@@ -89,7 +89,17 @@
 #'
 #' 
 #' @note 
-#' This function uses \code{\link[sqldf]{sqldf}} for optimization. 
+#' 
+#' This function uses specific version of the \code{\link[RMySQL]{RMySQL}} package. If it does not run correctly, try installing version 0.10.9 of the 
+#' \code{\link[RMySQL]{RMySQL}} package using:
+#' 
+#' > remove.packages("RMySQL") - If necessary
+#' 
+#' > install.packages("devtools) - If necessary
+#' 
+#' > devtools::install_version("RMySQL", version = "0.10.9", repos = "http://cran.us.r-project.org")  
+#'
+#' 
 #' 
 #' @examples 
 #' 
@@ -108,165 +118,171 @@
 #' 
 #' @keywords search
 #' 
+#' @import RMySQL
+#' @import DBI
 #' @importFrom stringr str_split
-#' @importFrom  utils View
-#' @import sqldf utils
+#' @importFrom utils View
 #' @export 
 
-BETS.search = function(description = "*",src,periodicity,unit,code,start,view=TRUE,lang="en"){
-  if(lang=="pt"){
-    githubURL<-("https://github.com/GreedBlink/databases/raw/master/base_final_ptv1.Rdata")
-    load(conn<-url(githubURL))
-    database="base_final_ptv1"
-    close(conn)
-  }
-  else{
-    githubURL<- "https://github.com/GreedBlink/databases/raw/master/bacen_v7.Rdata"
-    load(conn<-url(githubURL))
-    database="bacen_v7"
-    close(conn)
+BETS.search = function(description="*",src,periodicity,unit,code,start,view=TRUE,lang="en"){
+  
+  conn = dbConnect(MySQL(),db="bets",user="BETS_user",password="123456",host="200.20.164.178",port=3306)
+  
+  if(lang == "en"){
+    tb = "metadata_en"
+  } else {
+    tb = "metadata_pt"
   }
   
+   if(description == "*" && missing(src) && missing(periodicity) && missing(unit) && missing(code)){
+      query <- paste0("select * from ", tb)
+     #  results = dbGetQuery(conn, query)
+     #  results$description = iconv(results$description, from = "UTF-8")
+     #  invisible(dbDisconnect(conn))
+     # if(view==T){
+     #  return(View(results,"Metadata"))
+     #  }
+     #  else{
+     #    return(results)
+     #  }
+    } else {
   
+      if(missing(description) && missing(src) && missing(periodicity) && missing(unit) && missing(code)){
+        invisible(dbDisconnect(conn))
+        return(msg("No search parameters. Please set the values of one or more parameters."))    
+      }
+      
+      params = vector(mode = "character")
+      
+      if(!missing(description)){
+        
+        ## Break description parameters
+        and_params = vector(mode = "character")
+        or_params = vector(mode = "character")
+        
+        # Workaround
+        description = paste0(description, " ")
+        
+        # Do not match whole expressions
+        exprs = regmatches(description,gregexpr("~ ?'(.*?)'",description))[[1]]
+        
+        if(length(exprs) != 0){
+          for(i in 1:length(exprs)){
+            description = gsub(exprs[i], "", description)
+            exprs[i] = gsub("~", "", exprs[i])
+            exprs[i] = gsub("'", "", exprs[i])
+            exprs[i] = trimws(exprs[i])
+            and_params = c(and_params, paste0("description not like " ,"\'%", exprs[i] ,"%\'"))
+          }
+        }
+        
+        # Match whole expressions
+        exprs = regmatches(description,gregexpr("'(.*?)'",description))[[1]]
+        
+        if(length(exprs) != 0){
+          for(i in 1:length(exprs)){
+            description = gsub(exprs[i], "", description)
+            exprs[i] = gsub("'", "", exprs[i])
+            exprs[i] = trimws(exprs[i])
+            or_params = c(or_params, paste0("description like " ,"\'%", exprs[i] ,"%\'"))
+          }
+        }
+        
+        # Do not match words
+        words = regmatches(description,gregexpr("~ ?(.*?) ",description))[[1]]
+        
+        if(length(words) != 0){
+          for(i in 1:length(words)){
+            description = gsub(words[i], "", description)
+            words[i] = gsub("~", "", words[i])
+            words[i] = trimws(words[i])
+            and_params = c(and_params, paste0("description not like " ,"\'%", words[i] ,"%\'"))
+          }
+        }
+        
+        # Match words
+        words = str_split(description, " ")[[1]]
+        words = words[words != ""]
+        
+        if(length(words) != 0){
+          for(i in 1:length(words)){
+            or_params = c(or_params, paste0("description like " ,"\'%", words[i] ,"%\'"))
+          }
+        }
+        
+        if(length(and_params) > length(or_params)){
+          desc = and_params[1]
+          and_params = and_params[-1]
+        }
+        else {
+          desc = or_params[1]
+          or_params = or_params[-1]
+        }
+        
+        if(length(or_params) != 0){
+          for(i in 1:length(or_params)){
+            desc = paste(desc, "and", or_params[i])
+          }
+        }
+        
+        if(length(and_params) != 0){
+          for(i in 1:length(and_params)){
+            desc = paste(desc, "and", and_params[i])
+          }
+        }
+        
+        params = c(params, desc)
+      }
+      
+      if(!missing(src)){
+        params = c(params, paste0("source like " ,"\'%", src ,"%\'"))
+      }
+      
+      if(!missing(periodicity)){
+        params = c(params, paste0("periodicity like " ,"\'%", periodicity ,"%\'"))
+      }  
+      
+      if(!missing(unit)){
+        params = c(params, paste0("unit like " ,"\'%", unit ,"%\'"))
+      }  
+      
+      if(!missing(code)){
+        params = c(params, paste0("code like " ,"\'", code ,"\'"))
+      }
+      
+      if(!missing(start)){
+        params = c(params, paste0("start like " ,"\'", start ,"\'"))
+      }
+      
+      query = paste0("select * from ", tb, " where")
+      query = paste(query, params[1])
+      
+      if(length(params) != 1) {
+        for(i in 2:length(params)){
+          query = paste(query, "and", params[i])
+        }
+      }
+    }
   
-  if(description == "*" && missing(src) && missing(periodicity) && missing(unit) && missing(code)){
-    query <- paste0("select * from ", database)
-    results = sqldf(query)
+  results = dbGetQuery(conn, query)
+  results$description = iconv(results$description, from = "UTF-8")
+  results$unit = iconv(results$unit, from = "UTF-8")
+
+  count = dbGetQuery(conn,paste0("select count(*) from ", tb))
+  invisible(dbDisconnect(conn))
+  
+  if(nrow(results) > 0){
+    msg(paste("Found", nrow(results),"out of", count ,"time series.",sep=" "))
+    
+ 
     if(view==T){
       return(View(results,"Metadata"))
     }
     else{
       return(results)
     }
-  }else{
-    
-    
-    
-    if(missing(description) && missing(src) && missing(periodicity) && missing(unit) && missing(code)){
-      return(msg("No search parameters. Please set the values of one or more parameters."))    
-    }
-    
-    params = vector(mode = "character")
-    
-    if(!missing(description)){
-      
-      ## Break description parameters
-      and_params = vector(mode = "character")
-      or_params = vector(mode = "character")
-      
-      # Workaround
-      description = paste0(description, " ")
-      
-      # Do not match whole expressions
-      exprs = regmatches(description,gregexpr("~ ?'(.*?)'",description))[[1]]
-      
-      if(length(exprs) != 0){
-        for(i in 1:length(exprs)){
-          description = gsub(exprs[i], "", description)
-          exprs[i] = gsub("~", "", exprs[i])
-          exprs[i] = gsub("'", "", exprs[i])
-          exprs[i] = trimws(exprs[i])
-          and_params = c(and_params, paste0("Description not like " ,"\'%", exprs[i] ,"%\'"))
-        }
-      }
-      
-      # Match whole expressions
-      exprs = regmatches(description,gregexpr("'(.*?)'",description))[[1]]
-      
-      if(length(exprs) != 0){
-        for(i in 1:length(exprs)){
-          description = gsub(exprs[i], "", description)
-          exprs[i] = gsub("'", "", exprs[i])
-          exprs[i] = trimws(exprs[i])
-          or_params = c(or_params, paste0("Description like " ,"\'%", exprs[i] ,"%\'"))
-        }
-      }
-      
-      # Do not match words
-      words = regmatches(description,gregexpr("~ ?(.*?) ",description))[[1]]
-      
-      if(length(words) != 0){
-        for(i in 1:length(words)){
-          description = gsub(words[i], "", description)
-          words[i] = gsub("~", "", words[i])
-          words[i] = trimws(words[i])
-          and_params = c(and_params, paste0("Description not like " ,"\'%", words[i] ,"%\'"))
-        }
-      }
-      
-      # Match words
-      words = str_split(description, " ")[[1]]
-      words = words[words != ""]
-      
-      if(length(words) != 0){
-        for(i in 1:length(words)){
-          or_params = c(or_params, paste0("Description like " ,"\'%", words[i] ,"%\'"))
-        }
-      }
-      
-      if(length(and_params) > length(or_params)){
-        desc = and_params[1]
-        and_params = and_params[-1]
-      }
-      else {
-        desc = or_params[1]
-        or_params = or_params[-1]
-      }
-      
-      if(length(or_params) != 0){
-        for(i in 1:length(or_params)){
-          desc = paste(desc, "and", or_params[i])
-        }
-      }
-      
-      if(length(and_params) != 0){
-        for(i in 1:length(and_params)){
-          desc = paste(desc, "and", and_params[i])
-        }
-      }
-      
-      params = c(params, desc)
-    }
-    
-    if(!missing(src)){
-      params = c(params, paste0("source like " ,"\'%", src ,"%\'"))
-    }
-    
-    if(!missing(periodicity)){
-      params = c(params, paste0("periodicity like " ,"\'%", periodicity ,"%\'"))
-    }  
-    
-    if(!missing(unit)){
-      params = c(params, paste0("unit like " ,"\'%", unit ,"%\'"))
-    }  
-    
-    if(!missing(code)){
-      params = c(params, paste0("Codes like " ,"\'", code ,"\'"))
-    }
-    
-    if(!missing(start)){
-      params = c(params, paste0("start like " ,"\'", start ,"\'"))
-    }  
-    
-    query = paste("select Codes, Description, Periodicity, start, source, unit from", database ,"where")
-    query = paste(query, params[1])
-    
-    if(length(params) != 1) {
-      for(i in 2:length(params)){
-        query = paste(query, "and", params[i])
-      }
-    }
-    
-    metadata = sqldf(query)
-    
-    msg(paste("Found", nrow(metadata),"out of 39073 time series.",sep=" "))
-    
-    if(view==T){
-      return(
-        View(metadata,"Metadata"))
-    }
-    else{
-      return(metadata)
-    }
+  }
+  else{
+    msg("No series found. Try using another combination of search terms.")
   }
 }
